@@ -142,6 +142,17 @@ ml_gdome_di_saveDocumentToFile(value self, value doc, value name, value mode)
   CAMLreturn(Val_bool(res_));
 }
 
+value
+ml_gdome_di_saveDocumentToFileEnc(value self, value doc, value name, value encoding, value mode)
+{
+  CAMLparam5(self, doc, name, encoding, mode);
+  GdomeException exc_;
+  GdomeBoolean res_;
+  res_ = gdome_di_saveDocToFileEnc(DOMImplementation_val(self), Document_val(doc), String_val(name), String_val(encoding), Int_val(mode), &exc_);
+  if (exc_ != 0) throw_exception(exc_, "DOMImplementation.saveDocToFileEnc");
+  CAMLreturn(Val_bool(res_));
+}
+
 value
 ml_gdome_di_saveDocumentToMemory(value self, value doc, value mode)
 {
@@ -177,6 +188,42 @@ ml_gdome_di_saveDocumentToMemory(value self, value doc, value mode)
   CAMLreturn(caml_string);
 }
 
+value
+ml_gdome_di_saveDocumentToMemoryEnc(value self, value doc, value encoding, value mode)
+{
+  CAMLparam4(self, doc, encoding, mode);
+  GdomeException exc_;
+  char *c_string = NULL;
+  CAMLlocal1(caml_string);
+  gdome_di_saveDocToMemoryEnc(DOMImplementation_val(self),
+			      Document_val(doc),
+			      &c_string,
+			      String_val(encoding),
+			      Int_val(mode),
+			      &exc_);
+  /*
+   * ### XXX The buffer returned by gdome_di_saveDocToMemory should
+   * really be freed using a GDome function that calls the free() from
+   * the DOM library that allocated the buffer.  For now, just use
+   * free(), since libxml2 normally uses malloc() to allocate the
+   * memory.
+   */
+#define my_free free
+
+  if (exc_ != 0) {
+    if (c_string) {
+      my_free(c_string);
+    }
+    throw_exception(exc_, "DOMImplementation.saveDocToMemoryEnc");
+  }
+  if (!c_string) raise_out_of_memory();
+  caml_string = copy_string(c_string);
+
+  my_free(c_string);
+
+  CAMLreturn(caml_string);
+}
+
 value
 ml_gdome_di_enableEvent(value self, value doc, value name)
 {
