@@ -45,8 +45,12 @@ class domImplementation obj =
   method createDocumentFromMemory ~doc ?validatingMode ?keepEntities () = new document (IDOMImplementation.createDocumentFromMemory ~this:obj ~doc:((doc : domString)#as_DOMString) ?validatingMode ?keepEntities ())
   method saveDocumentToFile ~(doc : document) =
    IDOMImplementation.saveDocumentToFile ~this:obj ~doc:((doc : document)#as_Document)
+  method saveDocumentToFileEnc ~(doc : document) =
+   IDOMImplementation.saveDocumentToFileEnc ~this:obj ~doc:((doc : document)#as_Document)
  method saveDocumentToMemory ~(doc : document) =
   IDOMImplementation.saveDocumentToMemory ~this:obj ~doc:((doc : document)#as_Document)
+ method saveDocumentToMemoryEnc ~(doc : document) =
+  IDOMImplementation.saveDocumentToMemoryEnc ~this:obj ~doc:((doc : document)#as_Document)
  method enableEvent ~doc ~name = IDOMImplementation.enableEvent ~this:obj ~doc:((doc : document)#as_Document) ~name
  method disableEvent ~doc ~name = IDOMImplementation.disableEvent ~this:obj ~doc:((doc : document)#as_Document) ~name
  method eventIsEnabled ~doc ~name = IDOMImplementation.eventIsEnabled ~this:obj ~doc:((doc : document)#as_Document) ~name
