@@ -181,5 +181,16 @@ DOMImplementation::eventIsEnabled(const Document& doc, const char* name)
   return res_;
 }
 
+GdomeDOMImplementation* DOMImplementation::gdome_object() const
+{
+  if (gdome_obj != 0) {
+    GdomeException exc_ = 0;
+    gdome_di_ref(gdome_obj, &exc_);
+    if (exc_ != 0) throw DOMException(exc_, "DOMImplementation::gdome_object");
+  }
+
+  return gdome_obj;
+}
+
 }
 
